[Prism54-devel] Prism54 AP WPA using Hostap and WDS
Joerg Dorchain
joerg at dorchain.net
Mon Nov 8 16:43:46 UTC 2004
On Mon, Nov 08, 2004 at 10:56:42AM -0500, Luis R. Rodriguez wrote:
>
> > For dev_alloc, I have no old kernel tree at hand to look it up.
>
> I have looked into this and dev_alloc has been deprecated from 2.5 since
> last year. dev_alloc_name is, however, still availalable so that is what
> we'll use.
Patch included. It now compiles, but with warnings.
--- isl_wds.c.orig 2004-11-08 17:27:04.000000000 +0100
+++ isl_wds.c 2004-11-08 17:37:17.000000000 +0100
@@ -42,7 +42,7 @@
* DESCRIPTION: Add a WDSlink device to the system.
* On adding a WDSLINK to the MVC the following should be done:
* - Add a new device to the WDSlink devices list.
* - Create a device for this WDSlink (dev_alloc wds%d)
* - Register the just created dummy device (register_netdevice)
* - Bring the just created device up and running by calling dev_open.
* - Somehow the brigde needs to be told to accept the new interface.
@@ -119,9 +119,9 @@
* So we can actualy create a new device for this link
*/
sprintf(brifname, "%s_%d", dev->name, i);
- if (!(wdsp->wds_dev[i] = dev_alloc(brifname, &err))) {
+ if (!(err = dev_alloc_name(wdsp->wds_dev[i], brifname))) {
DEBUG(DBG_WDS | DBG_ERROR,
- "add_wds_link: dev_alloc() for WDS failed!\n");
+ "add_wds_link: dev_alloc_name() for WDS failed!\n");
return err;
}
/* Get a pointer to this WDS device */
-------------- next part --------------
A non-text attachment was scrubbed...
Name: not available
Type: application/pgp-signature
@@ -42,7 +42,7 @@
* On adding a WDSLINK to the MVC the following should be done:
* - Add a new device to the WDSlink devices list.
- * - Create a device for this WDSlink (dev_alloc wds%d)
+ * - Create a device for this WDSlink (dev_alloc_name wds%d)
* - Register the just created dummy device (register_netdevice)
* - Bring the just created device up and running by calling dev_open.
Size: 189 bytes
Desc: Digital signature
Url : http://prism54.org/pipermail/prism54-devel/attachments/20041108/3c446008/attachment.pgp
More information about the Prism54-devel
mailing list